"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ooth_i18n_1 = require("ooth-i18n");
const DEFAULT_LANGUAGE = 'en';
const DEFAULT_URLS = {
    verifyEmail: '/verify-email?token={verification-token}&userId={user-id}',
    resetPassword: '/reset-password?token={password-reset-token}&userId={user-id}',
};
const DEFAULT_TRANSLATIONS = {
    en: require('../i18n/en.json'),
};
function default_1({ name = 'local', ooth, from, siteName, sendMail, translations, urls, defaultLanguage, }) {
    const actualUrls = urls || DEFAULT_URLS;
    const actualTranslations = translations || DEFAULT_TRANSLATIONS;
    const __ = ooth_i18n_1.getI18n(actualTranslations, defaultLanguage || DEFAULT_LANGUAGE);
    const sendI18nMail = (email, language, name, values) => sendMail({
        from,
        to: email,
        subject: __(`${name}.subject`, values, language),
        body: __(`${name}.body`, values, language),
        html: __(`${name}.html`, values, language),
    });
    ooth.on(name, 'register', ({ email, verificationToken, _id, language, }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'welcome', {
            'site-name': siteName,
        });
        yield sendI18nMail(email, language, 'verify-email', {
            'site-name': siteName,
            'verify-email-url': ooth_i18n_1.interpolate(actualUrls.verifyEmail, {
                'verification-token': verificationToken,
                'user-id': _id,
            }),
        });
    }));
    ooth.on(name, 'generate-verification-token', ({ email, verificationToken, _id, language, }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'verify-email', {
            'site-name': siteName,
            'verify-email-url': ooth_i18n_1.interpolate(actualUrls.verifyEmail, {
                'verification-token': verificationToken,
                'user-id': _id,
            }),
        });
    }));
    ooth.on(name, 'set-email', ({ email, verificationToken, _id, language, }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'verify-email', {
            'site-name': siteName,
            'verify-email-url': ooth_i18n_1.interpolate(actualUrls.verifyEmail, {
                'verification-token': verificationToken,
                'user-id': _id,
            }),
        });
    }));
    ooth.on(name, 'verify', ({ email, language }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'email-verified', {
            'site-name': siteName,
        });
    }));
    ooth.on(name, 'forgot-password', ({ email, passwordResetToken, _id, language, }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'reset-password', {
            'site-name': siteName,
            'reset-password-url': ooth_i18n_1.interpolate(actualUrls.resetPassword, {
                'password-reset-token': passwordResetToken,
                'user-id': _id,
            }),
        });
    }));
    ooth.on(name, 'reset-password', ({ email, language }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'password-reset', {
            'site-name': siteName,
        });
    }));
    ooth.on(name, 'change-password', ({ email, language }) => __awaiter(this, void 0, void 0, function* () {
        yield sendI18nMail(email, language, 'password-changed', {
            'site-name': siteName,
        });
    }));
}
exports.default = default_1;
